use `qc`;

SET FOREIGN_KEY_CHECKS=0;

-- ----------------------------
-- Table structure for med_check_distribution_scheme
-- ----------------------------
DROP TABLE IF EXISTS `med_check_distribution_scheme`;
CREATE TABLE `med_check_distribution_scheme` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `dept_ids` varchar(1024) DEFAULT NULL COMMENT '住院科室ID集合(多个用逗号隔开)',
  `dept_names` varchar(1024) DEFAULT NULL COMMENT '住院科室名称集合(多个用逗号隔开)',
  `scheme_name` varchar(60) NOT NULL COMMENT '方案名称',
  `stage` char(3) NOT NULL DEFAULT '0' COMMENT '核查病历阶段(运行病历（未出院）:0、  运行病历（已出院）:1、 终末病历:2)',
  `in_time_frame` int(8) DEFAULT NULL COMMENT '入院日期-近多少天',
  `out_time_frame` int(8) DEFAULT NULL COMMENT '出院日期-近多少天',
  `level` varchar(32) DEFAULT NULL COMMENT '病历等级',
  `behospital_type` varchar(32) DEFAULT NULL COMMENT '病历类型(普通病人、手术病人、疑难病人、危重病人、抢救病人、死亡病人)',
  `check_status` char(3) NOT NULL DEFAULT '0' COMMENT '核查状态(0:未核查 1:已核查)',
  `is_check_all` char(3) NOT NULL DEFAULT '0' COMMENT '全部核查(0:无 1:全部)',
  `check_ratio` int(8) DEFAULT NULL COMMENT '核查比例',
  `check_num` int(8) DEFAULT NULL COMMENT '核查数量',
  `distribution_type` char(3) NOT NULL DEFAULT '0' COMMENT '分配方式(0:平均分配;1:按比例分配) 默认平均分配',
  `task_time_limit` int(8) DEFAULT NULL COMMENT '任务时限',
  `is_timing` char(3) NOT NULL DEFAULT '0' COMMENT '是否定时任务(0:非定时任务 1:是定时任务)',
  `scheduled_task_expression` varchar(255) DEFAULT NULL COMMENT '任务生成时间表达式',
  `is_deleted` char(3) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='核查分配方案表';

-- ----------------------------
-- Records of med_check_distribution_scheme
-- ----------------------------

-- ----------------------------
-- Table structure for med_check_distribution_scheme_person
-- ----------------------------
DROP TABLE IF EXISTS `med_check_distribution_scheme_person`;
CREATE TABLE `med_check_distribution_scheme_person` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `scheme_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '方案id',
  `check_ratio` int(8) DEFAULT NULL COMMENT '核查比例',
  `check_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '核查员id',
  `check_name` varchar(60) DEFAULT NULL COMMENT '核查员姓名',
  `check_time` datetime DEFAULT NULL COMMENT '核查时间',
  `is_deleted` char(3) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='核查分配方案人员表';

-- ----------------------------
-- Records of med_check_distribution_scheme_person
-- ----------------------------

-- ----------------------------
-- Table structure for med_check_record
-- ----------------------------
DROP TABLE IF EXISTS `med_check_record`;
CREATE TABLE `med_check_record` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(16) NOT NULL COMMENT '病人住院ID',
  `check_type` char(3) NOT NULL DEFAULT '2' COMMENT '核查类型（0病历，1病案首页，2全部）',
  `job_creator` bigint(20) NOT NULL DEFAULT '0' COMMENT '核查任务创建人编号',
  `job_creator_name` varchar(60) DEFAULT NULL COMMENT '核查任务创建人',
  `job_create_time` datetime DEFAULT NULL COMMENT '核查任务生成时间',
  `job_type` char(3) NOT NULL DEFAULT '0' COMMENT '核查任务类型（0-科室任务 1-质控科 2-院级）',
  `job_distributor` bigint(20) NOT NULL DEFAULT '0' COMMENT '核查任务分配人编号',
  `job_distribution_name` varchar(60) DEFAULT NULL COMMENT '核查任务分配人姓名',
  `job_distribution_time` datetime DEFAULT NULL COMMENT '核查任务分配时间',
  `work_flow_node_id` bigint(20) NOT NULL COMMENT '当前工作流节点id',
  `job_end_time` datetime DEFAULT NULL COMMENT '任务截止日期',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='核查记录表';

-- ----------------------------
-- Records of med_check_record
-- ----------------------------

-- ----------------------------
-- Table structure for med_check_record_examine
-- ----------------------------
DROP TABLE IF EXISTS `med_check_record_examine`;
CREATE TABLE `med_check_record_examine` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `check_record` bigint(20) NOT NULL COMMENT '核查记录id',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(16) NOT NULL COMMENT '病人住院ID',
  `check_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '核查人编号',
  `check_name` varchar(60) DEFAULT NULL COMMENT '核查人姓名',
  `check_time` datetime DEFAULT NULL COMMENT '核查时间',
  `status` char(3) NOT NULL DEFAULT '0' COMMENT '核查状态（0待核查，1已核查）',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='核查记录审批表';

-- ----------------------------
-- Records of med_check_record_examine
-- ----------------------------


/**
sys_menu 新增核查相关菜单
 */
INSERT INTO `sys_menu` (`id`, `is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `name`, `parent_id`, `code`, `show_status`, `maintain_status`, `order_no`, `remark`) VALUES ('140', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控核查', '-1', 'YH-ZKHC', '1', '1', '11', '用户-质控核查');
INSERT INTO `sys_menu` (`id`, `is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `name`, `parent_id`, `code`, `show_status`, `maintain_status`, `order_no`, `remark`) VALUES ('141', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '科室核查', '140', 'YH-ZKHC-KSHC', '1', '1', '1', '用户-质控核查-科室核查');
INSERT INTO `sys_menu` (`id`, `is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `name`, `parent_id`, `code`, `show_status`, `maintain_status`, `order_no`, `remark`) VALUES ('142', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控科核查', '140', 'YH-ZKHC-ZKKHC', '1', '1', '2', '用户-质控核查-质控科核查');
INSERT INTO `sys_menu` (`id`, `is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `name`, `parent_id`, `code`, `show_status`, `maintain_status`, `order_no`, `remark`) VALUES ('143', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '院级核查', '140', 'YH-ZKHC-YJHC', '1', '1', '3', '用户-质控核查-院级核查');

/**
sys_permission 新增系统资源信息
 */


/**
sys_menu_permission 新增菜单关联的资源
 */

/**
sys_role_menu 新增角色和菜单的映射信息
 */
INSERT INTO `sys_role_menu` (`is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `role_id`, `menu_id`, `remark`) VALUES ( 'N', '2021-06-03 02:03:31', '2021-06-03 02:03:31', '179', '179', '4', '140', NULL);
INSERT INTO `sys_role_menu` (`is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `role_id`, `menu_id`, `remark`) VALUES ( 'N', '2021-06-03 02:03:31', '2021-06-03 02:03:31', '179', '179', '4', '141', NULL);
INSERT INTO `sys_role_menu` (`is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `role_id`, `menu_id`, `remark`) VALUES ( 'N', '2021-06-03 02:03:31', '2021-06-03 02:03:31', '179', '179', '5', '140', NULL);
INSERT INTO `sys_role_menu` (`is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `role_id`, `menu_id`, `remark`) VALUES ( 'N', '2021-06-03 02:03:31', '2021-06-03 02:03:31', '179', '179', '5', '142', NULL);
INSERT INTO `sys_role_menu` (`is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `role_id`, `menu_id`, `remark`) VALUES ( 'N', '2021-06-03 02:03:31', '2021-06-03 02:03:31', '179', '179', '6', '140', NULL);
INSERT INTO `sys_role_menu` (`is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `role_id`, `menu_id`, `remark`) VALUES ( 'N', '2021-06-03 02:03:31', '2021-06-03 02:03:31', '179', '179', '6', '143', NULL);
/**
sys_role_permission 新增角色和资源的映射信息
 */
