package com.diagbot.entity;

import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import lombok.Getter;
import lombok.Setter;

import java.time.LocalDateTime;
import java.io.Serializable;

/**
 * <p>
 * 核查分配方案表
 * </p>
 *
 * @author songxl
 * @since 2022-05-18
 */
@TableName("med_check_distribution_scheme")
@Getter
@Setter
public class CheckDistributionScheme implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 医院ID
     */
    private Long hospitalId;

    /**
     * 住院科室ID集合(多个用逗号隔开)
     */
    private String deptIds;

    /**
     * 住院科室名称集合(多个用逗号隔开)
     */
    private String deptNames;

    /**
     * 方案名称
     */
    private String schemeName;

    /**
     * 核查病历阶段(运行病历（未出院）:0、  运行病历（已出院）:1、 终末病历:2)
     */
    private String stage;

    /**
     * 入院日期-近多少天
     */
    private Integer inTimeFrame;

    /**
     * 出院日期-近多少天
     */
    private Integer outTimeFrame;

    /**
     * 病历等级
     */
    private String level;

    /**
     * 病历类型(普通病人、手术病人、疑难病人、危重病人、抢救病人、死亡病人)
     */
    private String behospitalType;

    /**
     * 核查状态(0:未核查 1:已核查)
     */
    private String checkStatus;

    /**
     * 全部核查(0:无 1:全部)
     */
    private String isCheckAll;

    /**
     * 核查比例
     */
    private Integer checkRatio;

    /**
     * 核查数量
     */
    private Integer checkNum;

    /**
     * 分配方式(0:平均分配;1:按比例分配) 默认平均分配
     */
    private String distributionType;

    /**
     * 任务时限
     */
    private Integer taskTimeLimit;

    /**
     * 是否定时任务(0:非定时任务 1:是定时任务)
     */
    private String isTiming;

    /**
     * 任务生成时间表达式
     */
    private String scheduledTaskExpression;

    /**
     * 是否删除,N:未删除，Y:删除
     */
    private String isDeleted;

    /**
     * 记录创建时间
     */
    private LocalDateTime gmtCreate;

    /**
     * 记录修改时间,如果时间是1970年则表示纪录未修改
     */
    private LocalDateTime gmtModified;

    /**
     * 创建人，0表示无创建人值
     */
    private String creator;

    /**
     * 修改人,如果为0则表示纪录未修改
     */
    private String modifier;

    /**
     * 备注
     */
    private String remark;


    @Override
    public String toString() {
        return "CheckDistributionScheme{" +
            "id=" + id +
            ", hospitalId=" + hospitalId +
            ", deptIds=" + deptIds +
            ", deptNames=" + deptNames +
            ", schemeName=" + schemeName +
            ", stage=" + stage +
            ", inTimeFrame=" + inTimeFrame +
            ", outTimeFrame=" + outTimeFrame +
            ", level=" + level +
            ", behospitalType=" + behospitalType +
            ", checkStatus=" + checkStatus +
            ", isCheckAll=" + isCheckAll +
            ", checkRatio=" + checkRatio +
            ", checkNum=" + checkNum +
            ", distributionType=" + distributionType +
            ", taskTimeLimit=" + taskTimeLimit +
            ", isTiming=" + isTiming +
            ", isDeleted=" + isDeleted +
            ", gmtCreate=" + gmtCreate +
            ", gmtModified=" + gmtModified +
            ", creator=" + creator +
            ", modifier=" + modifier +
            ", remark=" + remark +
        "}";
    }
}
